@@ -1,7 +1,7 @@
 use strict;
 use warnings;
-package Software::License::OpenSSL;
-$Software::License::OpenSSL::VERSION = '0.103012';
+package Software::License::OpenSSL 0.104006;
+
 use parent 'Software::License';
 # ABSTRACT: The OpenSSL License
 
@@ -11,6 +11,7 @@ sub name { 'OpenSSL License' }
 sub url  { 'http://www.openssl.org/source/license.html' }
 sub meta_name  { 'open_source' }
 sub meta2_name { 'openssl' }
+sub spdx_expression  { 'OpenSSL' }
 
 sub _ssleay {
   my ($self) = @_;
@@ -32,15 +33,29 @@ Software::License::OpenSSL - The OpenSSL License
 
 =head1 VERSION
 
-version 0.103012
+version 0.104006
+
+=head1 PERL VERSION
+
+This module is part of CPAN toolchain, or is treated as such.  As such, it
+follows the agreement of the Perl Toolchain Gang to require no newer version
+of perl than one released in the last ten years.  This version may change by
+agreement of the Toolchain Gang, but for now is governed by the L<Lancaster
+Consensus|https://github.com/Perl-Toolchain-Gang/toolchain-site/blob/master/lancaster-consensus.md>
+of 2013 and the Lyon Amendment of 2023 (described at the linked-to document).
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo Signes.
+This software is copyright (c) 2024 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
